INSERT OVERWRITE foo.`testing123456`
SELECT t0.*
FROM functional_alltypes t0
LIMIT 10